@@ -58,14 +58,15 @@ setup(
   version=version,
   description='Blogging client for Maemo',
   long_description="""
-Cross-blog client for Maemo
-This version is alpha, so it is not recommended for usual users.
-But if you want to help project you can try to use application.
-Please send bugs to scribo@cs.karelia.ru.
-In future local cache module can be changed so you must remove all application
-data from ~/.scribo before installation of new version. 
-Use "cd ~; rm -rf ./.scribo" for this.
-Thank you.
+Cross-Blog Client.
+This version is alpha; it is oriented to developers, not regular users.
+You can help the Scribo project if you try our application.
+Please send your comments to maemo-scribo@cs.karelia.ru
+and bugs to http://oss.fruct.org/bugzilla/.
+Note that the Scribo local cache can be changed in further releases.
+You MUST remove all application data from ~/.scribo before installing,
+e.g. with "rm -rf ~/.scribo".
+Thank you
 """,
   author="Zaiceva Dyana, Mezhenyn Artyom, Sannikov Alexander, Germanov Kyrill",
   author_email='<maemo-scribo@cs.karelia.ru>',
